create_basic_account

Function create_basic_account 

pub async fn create_basic_account(
    client: &mut Client,
    keystore: FilesystemKeyStore<StdRng>,
) -> Result<(Account, SecretKey), ClientError>
Creates a basic account with a random key and adds it to the client.

Arguments

  • client - The Miden client to interact with.
  • keystore - The keystore to store the account’s secret key.

Returns

Returns a tuple containing the created Account and the associated SecretKey.