pub async fn wait_for_note(
client: &mut Client,
expected: &Note,
) -> Result<(), ClientError>Expand description
Waits for the exact note to be available and committed.
This function will block until the specified note is found in the output notes and is committed.
Arguments
client- The Miden client used to interact with the blockchain.expected- The note to wait for.
Returns
Returns a Result indicating whether the note was found and committed.