create_library

Function create_library 

pub fn create_library(
    account_code: String,
    library_path: &str,
) -> Result<Library, Box<dyn Error>>
Creates a Miden library from the provided account code and library path.

Arguments

  • account_code - The account code in MASM format.
  • library_path - The path where the library is located.

Returns

Returns the resulting Library if successful, or an error if the library cannot be created.