Function create_tx_script
Source pub fn create_tx_script(
script_code: String,
library: Option<Library>,
) -> Result<TransactionScript, Error>
Creates a transaction script based on the provided code and optional library.
Arguments
script_code - The code for the transaction script, typically written in MASM.
library - An optional library to use with the script.
Returns
Returns a TransactionScript if successfully created, or an error.